@@ -62,7 +62,11 @@ def get_git_url(commit_hash: bool = True) -> str:
     :return: The https url of the current git repo.
     """
     # Get git url (either https or ssh)
-    url = check_output(['git', 'remote', 'get-url', 'origin'])
+    try:
+        url = check_output(['git', 'remote', 'get-url', 'origin'])
+    except subprocess.CalledProcessError:
+        # For git versions <2.0
+        url = check_output(['git' 'config' '--get' 'remote.origin.url'])
 
     # Remove .git at end
     url = url[:-len('.git')]
@@ -242,7 +246,7 @@ def get_literals(literal: Literal, variable: str) -> Tuple[Callable[[str], Any],
         raise ValueError('All literals must have unique string representations')
 
     def var_type(arg: str) -> Any:
-        return str_to_literal[arg]
+        return str_to_literal.get(arg, arg)
 
     return var_type, literals
 
